
import requests
from yurolabs.config import load_key

BASE = "https://your-modal-backend.example.com"

def deploy_model(model_path: str):
    key = load_key()
    files = {"file": open(model_path, "rb")}
    r = requests.post(f"{BASE}/deploy", files=files, headers={"Authorization": key})
    return r.json()

def run_inference(data):
    key = load_key()
    r = requests.post(f"{BASE}/infer", json={"data": data}, headers={"Authorization": key})
    return r.json()



import typer
from rich import print

from yurolabs.config import save_key
from yurolabs.api import deploy_model, run_inference

app = typer.Typer(help="Yuro model management CLI.")

@app.command()
def login(key: str):
    save_key(key)
    print("[green]API key saved![/green]")

@app.command()
def deploy(model: str):
    print("[cyan]Deploying model...[/cyan]")
    out = deploy_model(model)
    print(out)

@app.command()
def test(input: str):
    print("[cyan]Running inference...[/cyan]")
    out = run_inference(input)
    print(out)




import os
from appdirs import user_config_dir

CONFIG_DIR = user_config_dir("yurolabs")
CONFIG_FILE = os.path.join(CONFIG_DIR, "config")

def save_key(key: str):
    os.makedirs(CONFIG_DIR, exist_ok=True)
    with open(CONFIG_FILE, "w") as f:
        f.write(key)

def load_key():
    with open(CONFIG_FILE) as f:
        return f.read().strip()
